@@ -7,9 +7,9 @@
  * 
  * JasPer License Version 2.0
  * 
+ * Copyright (c) 2001-2006 Michael David Adams
  * Copyright (c) 1999-2000 Image Power, Inc.
  * Copyright (c) 1999-2000 The University of British Columbia
- * Copyright (c) 2001-2003 Michael David Adams
  * 
  * All rights reserved.
  * 
@@ -158,11 +158,8 @@ jas_cmprof_t *jas_cmprof_createfromclrspc(int clrspc)
 			goto error;
 		if (!(prof = jas_cmprof_createfromiccprof(iccprof)))
 			goto error;
-#if 0
 		jas_iccprof_destroy(iccprof);
-#else
-		prof->iccprof = iccprof;
-#endif
+		iccprof = 0;
 		if (!jas_clrspc_isgeneric(clrspc))
 			prof->clrspc = clrspc;
 		break;
@@ -250,6 +247,10 @@ jas_cmprof_t *jas_cmprof_createfromiccprof(jas_iccprof_t *iccprof)
 	jas_cmpxformseq_t *fwdpxformseq;
 	jas_cmpxformseq_t *revpxformseq;
 
+	prof = 0;
+	fwdpxformseq = 0;
+	revpxformseq = 0;
+
 	if (!(prof = jas_cmprof_create()))
 		goto error;
 	jas_iccprof_gethdr(iccprof, &icchdr);
@@ -292,7 +293,18 @@ jas_cmprof_t *jas_cmprof_createfromiccprof(jas_iccprof_t *iccprof)
 #endif
 
 	return prof;
+
 error:
+	if (fwdpxformseq) {
+		jas_cmpxformseq_destroy(fwdpxformseq);
+	}
+	if (revpxformseq) {
+		jas_cmpxformseq_destroy(revpxformseq);
+	}
+	if (prof) {
+		jas_cmprof_destroy(prof);
+	}
+
 	return 0;
 }
 
@@ -343,6 +355,8 @@ jas_cmprof_t *jas_cmprof_copy(jas_cmprof_t *prof)
 	}
 	return newprof;
 error:
+	if (newprof)
+		jas_cmprof_destroy(newprof);
 	return 0;
 }
 
@@ -446,6 +460,8 @@ jas_cmxform_t *jas_cmxform_create(jas_cmprof_t *inprof, jas_cmprof_t *outprof,
 	}
 	return xform;
 error:
+	if (xform)
+		jas_cmxform_destroy(xform);
 	return 0;
 }
 
@@ -602,6 +618,8 @@ static jas_cmpxformseq_t *jas_cmpxformseq_copy(jas_cmpxformseq_t *pxformseq)
 		goto error;
 	return newpxformseq;
 error:
+	if (newpxformseq)
+		jas_cmpxformseq_destroy(newpxformseq);
 	return 0;
 }
 
@@ -692,8 +710,8 @@ static int jas_cmpxformseq_resize(jas_cmpxformseq_t *pxformseq, int n)
 {
 	jas_cmpxform_t **p;
 	assert(n >= pxformseq->numpxforms);
-	p = (!pxformseq->pxforms) ? jas_malloc(n * sizeof(jas_cmpxform_t *)) :
-	  jas_realloc(pxformseq->pxforms, n * sizeof(jas_cmpxform_t *));
+	p = (!pxformseq->pxforms) ? jas_alloc2(n, sizeof(jas_cmpxform_t *)) :
+	  jas_realloc2(pxformseq->pxforms, n, sizeof(jas_cmpxform_t *));
 	if (!p) {
 		return -1;
 	}
@@ -877,13 +895,13 @@ static int jas_cmshapmatlut_set(jas_cmshapmatlut_t *lut, jas_icccurv_t *curv)
 	jas_cmshapmatlut_cleanup(lut);
 	if (curv->numents == 0) {
 		lut->size = 2;
-		if (!(lut->data = jas_malloc(lut->size * sizeof(jas_cmreal_t))))
+		if (!(lut->data = jas_alloc2(lut->size, sizeof(jas_cmreal_t))))
 			goto error;
 		lut->data[0] = 0.0;
 		lut->data[1] = 1.0;
 	} else if (curv->numents == 1) {
 		lut->size = 256;
-		if (!(lut->data = jas_malloc(lut->size * sizeof(jas_cmreal_t))))
+		if (!(lut->data = jas_alloc2(lut->size, sizeof(jas_cmreal_t))))
 			goto error;
 		gamma = curv->ents[0] / 256.0;
 		for (i = 0; i < lut->size; ++i) {
@@ -891,7 +909,7 @@ static int jas_cmshapmatlut_set(jas_cmshapmatlut_t *lut, jas_icccurv_t *curv)
 		}
 	} else {
 		lut->size = curv->numents;
-		if (!(lut->data = jas_malloc(lut->size * sizeof(jas_cmreal_t))))
+		if (!(lut->data = jas_alloc2(lut->size, sizeof(jas_cmreal_t))))
 			goto error;
 		for (i = 0; i < lut->size; ++i) {
 			lut->data[i] = curv->ents[i] / 65535.0;
@@ -941,7 +959,7 @@ static int jas_cmshapmatlut_invert(jas_cmshapmatlut_t *invlut,
 			return -1;
 		}
 	}
-	if (!(invlut->data = jas_malloc(n * sizeof(jas_cmreal_t))))
+	if (!(invlut->data = jas_alloc2(n, sizeof(jas_cmreal_t))))
 		return -1;
 	invlut->size = n;
 	for (i = 0; i < invlut->size; ++i) {
@@ -981,9 +999,9 @@ assert(0);
 	}
 #if 0
 for (i=0;i<lut->size;++i)
-	fprintf(stderr, "lut[%d]=%f ", i, lut->data[i]);
+	jas_eprintf("lut[%d]=%f ", i, lut->data[i]);
 for (i=0;i<invlut->size;++i)
-	fprintf(stderr, "invlut[%d]=%f ", i, invlut->data[i]);
+	jas_eprintf("invlut[%d]=%f ", i, invlut->data[i]);
 #endif
 	return 0;
 }
@@ -995,7 +1013,7 @@ static int jas_cmshapmat_invmat(jas_cmreal_t out[3][4], jas_cmreal_t in[3][4])
 	  - in[0][1] * (in[1][0] * in[2][2] - in[1][2] * in[2][0])
 	  + in[0][2] * (in[1][0] * in[2][1] - in[1][1] * in[2][0]);
 #if 0
-fprintf(stderr, "delta=%f\n", d);
+jas_eprintf("delta=%f\n", d);
 #endif
 	if (JAS_ABS(d) < 1e-6)
 		return -1;
@@ -1012,11 +1030,11 @@ fprintf(stderr, "delta=%f\n", d);
 	out[1][3] = -in[1][3];
 	out[2][3] = -in[2][3];
 #if 0
-fprintf(stderr, "[ %f %f %f %f ]\n[ %f %f %f %f ]\n[ %f %f %f %f ]\n",
+jas_eprintf("[ %f %f %f %f ]\n[ %f %f %f %f ]\n[ %f %f %f %f ]\n",
 in[0][0], in[0][1], in[0][2], in[0][3],
 in[1][0], in[1][1], in[1][2], in[1][3],
 in[2][0], in[2][1], in[2][2], in[2][3]);
-fprintf(stderr, "[ %f %f %f %f ]\n[ %f %f %f %f ]\n[ %f %f %f %f ]\n",
+jas_eprintf("[ %f %f %f %f ]\n[ %f %f %f %f ]\n[ %f %f %f %f ]\n",
 out[0][0], out[0][1], out[0][2], out[0][3],
 out[1][0], out[1][1], out[1][2], out[1][3],
 out[2][0], out[2][1], out[2][2], out[2][3]);
@@ -1118,11 +1136,15 @@ static int triclr(jas_iccprof_t *iccprof, int op, jas_cmpxformseq_t **retpxforms
 	jas_cmpxformseq_t *pxformseq;
 	jas_cmreal_t mat[3][4];
 	jas_cmshapmatlut_t lut;
-	jas_cmshapmatlut_init(&lut);
+
+	pxform = 0;
+	pxformseq = 0;
 	for (i = 0; i < 3; ++i) {
 		trcs[i] = 0;
 		cols[i] = 0;
 	}
+	jas_cmshapmatlut_init(&lut);
+
 	if (!(trcs[0] = jas_iccprof_getattr(iccprof, JAS_ICC_TAG_REDTRC)) ||
 	  !(trcs[1] = jas_iccprof_getattr(iccprof, JAS_ICC_TAG_GRNTRC)) ||
 	  !(trcs[2] = jas_iccprof_getattr(iccprof, JAS_ICC_TAG_BLUTRC)) ||
@@ -1187,7 +1209,24 @@ static int triclr(jas_iccprof_t *iccprof, int op, jas_cmpxformseq_t **retpxforms
 	jas_cmpxform_destroy(pxform);
 	*retpxformseq = pxformseq;
 	return 0;
+
 error:
+
+	for (i = 0; i < 3; ++i) {
+		if (trcs[i]) {
+			jas_iccattrval_destroy(trcs[i]);
+		}
+		if (cols[i]) {
+			jas_iccattrval_destroy(cols[i]);
+		}
+	}
+	if (pxformseq) {
+		jas_cmpxformseq_destroy(pxformseq);
+	}
+	if (pxform) {
+		jas_cmpxform_destroy(pxform);
+	}
+
 	return -1;
 }
 
